package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcJbsjndfltj;
import org.apache.ibatis.annotations.Param;

/**
 * 举报事件年度分类统计Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcJbsjndfltjMapper 
{
    /**
     * 查询举报事件年度分类统计
     * 
     * @param id 举报事件年度分类统计主键
     * @return 举报事件年度分类统计
     */
    public TcJbsjndfltj selectTcJbsjndfltjById(Long id);

    /**
     * 查询举报事件年度分类统计列表
     * 
     * @param tcJbsjndfltj 举报事件年度分类统计
     * @return 举报事件年度分类统计集合
     */
    public List<TcJbsjndfltj> selectTcJbsjndfltjList(TcJbsjndfltj tcJbsjndfltj);

    /**
     * 新增举报事件年度分类统计
     * 
     * @param tcJbsjndfltj 举报事件年度分类统计
     * @return 结果
     */
    public int insertTcJbsjndfltj(TcJbsjndfltj tcJbsjndfltj);

    /**
     * 修改举报事件年度分类统计
     * 
     * @param tcJbsjndfltj 举报事件年度分类统计
     * @return 结果
     */
    public int updateTcJbsjndfltj(TcJbsjndfltj tcJbsjndfltj);

    /**
     * 删除举报事件年度分类统计
     * 
     * @param id 举报事件年度分类统计主键
     * @return 结果
     */
    public int deleteTcJbsjndfltjById(Long id);

    /**
     * 批量删除举报事件年度分类统计
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcJbsjndfltjByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
