package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcJbmap;
import com.ruoyi.tcZz.domain.TcWljg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcJbsjndfltj;
import com.ruoyi.tcZz.service.ITcJbsjndfltjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 举报事件年度分类统计Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api("举报事件年度分类统计")
@RequestMapping("/tcZz/netManage/jbsjndfltj")
public class TcJbsjndfltjController extends BaseController {
    @Autowired
    private ITcJbsjndfltjService tcJbsjndfltjService;

    /**
     * 查询举报事件年度分类统计列表
     */
    @ApiOperation("查询举报事件年度分类统计列表")
    @GetMapping("/list")
    public TableDataInfo list(TcJbsjndfltj tcJbsjndfltj) {
        startPage();
        List<TcJbsjndfltj> list = tcJbsjndfltjService.selectTcJbsjndfltjList(tcJbsjndfltj);
        return getDataTable(list);
    }

    /**
     * 导出举报事件年度分类统计列表
     */
    @ApiOperation("导出举报事件年度分类统计列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcJbsjndfltj tcJbsjndfltj) {
        List<TcJbsjndfltj> list = tcJbsjndfltjService.selectTcJbsjndfltjList(tcJbsjndfltj);
        ExcelUtil<TcJbsjndfltj> util = new ExcelUtil<TcJbsjndfltj>(TcJbsjndfltj.class);
        util.exportExcel(response, list, "举报事件年度分类统计数据");
    }

    /**
     * 获取举报事件年度分类统计详细信息
     */
    @ApiOperation("获取举报事件年度分类统计详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcJbsjndfltjService.selectTcJbsjndfltjById(id));
    }

    /**
     * 新增举报事件年度分类统计
     */
    @ApiOperation("新增举报事件年度分类统计")
    @PostMapping
    public AjaxResult add(@RequestBody TcJbsjndfltj tcJbsjndfltj) {
        return toAjax(tcJbsjndfltjService.insertTcJbsjndfltj(tcJbsjndfltj));
    }

    /**
     * 修改举报事件年度分类统计
     */
    @ApiOperation("修改举报事件年度分类统计")
    @PutMapping
    public AjaxResult edit(@RequestBody TcJbsjndfltj tcJbsjndfltj) {
        return toAjax(tcJbsjndfltjService.updateTcJbsjndfltj(tcJbsjndfltj));
    }

    /**
     * 删除举报事件年度分类统计
     */
    @ApiOperation("删除举报事件年度分类统计")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcJbsjndfltjService.deleteTcJbsjndfltjByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcJbsjndfltj> util = new ExcelUtil<TcJbsjndfltj>(TcJbsjndfltj.class);
        List<TcJbsjndfltj> tcJbsjndfltjList = util.importExcel(file.getInputStream());
        tcJbsjndfltjService.importUser(tcJbsjndfltjList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcJbsjndfltjService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcJbsjndfltj> util = new ExcelUtil<TcJbsjndfltj>(TcJbsjndfltj.class);
        util.importTemplateExcel(response, " 举报事件年度分类统计");
    }
}
